pygeodesy.named._Named

Package pygeodesy :: Module named :: Class _Named |
[frames] | no frames]

# Class _Named

    object --+
             |
            _Named

Known Subclasses:
  - _NamedBase
  - , _NamedTuple
  - , angles.Ang
  - , unitsBase._NamedUnit
  - , booleans._CompositeBase
  - , booleans._LatLonBool
  - , ecefLocals._EcefLocal
  - , ellipses.Ellipse
  - , elliptic.Elliptic
  - , fsums.Fsum
  - , fstats._FstatsNamed
  - , frechet.Frechet
  - , heights._HeightNamed
  - , hausdorff.Hausdorff
  - , iters._BaseIter
  - , _NamedDict
  - , trf.TRFXform
  - , auxilats.auxAngle.AuxAngle
  - , booleans._Clip
  - , clipy._CS
  - , clipy._SH
  - , geoids._Gpars

(INTERNAL) Root class for named objects.

Instance Methods
__format__(self, fmt) Not implemented. |
__imatmul__(self, other) Not implemented. |
__matmul__(self, other) Not implemented. |
__repr__(self) Default `repr(self)`. |
__rmatmul__(self, other) Not implemented. |
__str__(self) Default `str(self)`. |
attrs(self, *names, **sep_Nones_pairs_kwds) Join named attributes as name=value strings, with `float`s formatted by function pygeodesy.fstr. |
classof(self, *args, **kwds) Create another instance of this very class. |
copy(self, deep=False, **name) Make a shallow or deep copy of this instance. |
dup(self, deep=False, **items) Duplicate this instance, replacing some attributes. |
methodname(self, which) Get a method `[module.]class.method` name of this object (`str`). |
rename(self, name) Change the name. |
renamed(self, name) Change the name. |
toRepr(self, **unused) Default `repr(self)`. |
toStr(self, **unused) Default `str(self)`. |
toStr2(self, **kwds) DEPRECATED on 23.10.07, use method `toRepr`. |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| classname Get this object's `[module.]class` name (`str`), see property `.classnaming` and function `classnaming`.
| classnaming Class `property` with a `.name` attribute.
| iteration Get the most recent iteration number (`int`) or `None` if not available or not applicable.
| name Class `property` with a `.name` attribute.
| named Get the name or class name or `""` (`str`).
| named2 Get the `class` name and/or the repr(name) or `""` (`str`).
| named3 Get the prefixed `class` name and/or the name or `""` (`str`).
| named4 Get the `package.module.class` name and/or the name or `""` (`str`).
| sizeof Get the current size in `bytes` of this instance (`int`).
| typename Get this object's type name (`str`).
Inherited from `object`: `__class__`

Method Details

### __format__ (self, fmt) |
Not implemented. Overrides: object.__format__

### __repr__ (self) (Representation operator) |
Default `repr(self)`. Overrides: object.__repr__

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__

### attrs (self, *names, **sep_Nones_pairs_kwds) |
Join named attributes as name=value strings, with `float`s formatted by function pygeodesy.fstr. Arguments: `names` - The attribute names, all positional (`str`). `sep_Nones_pairs_kwds` - Keyword arguments for function pygeodesy.pairs, except `sep=", "` and `Nones=True` to in-/exclude missing or `None`-valued attributes. Returns: All `name=value` pairs, joined by `sep` (`str`). See Also: Functions pygeodesy.attrs, pygeodesy.pairs and pygeodesy.fstr

### classof (self, *args, **kwds) |
Create another instance of this very class. Arguments: `args` - Optional, positional arguments. `kwds` - Optional, keyword arguments. Returns: New instance (self.__class__).

### copy (self, deep=False, **name) |
Make a shallow or deep copy of this instance. Arguments: `deep` - If `True`, make a deep, otherwise a shallow copy (`bool`). `name` - Optional, non-empty `name=NN` (`str`). Returns: The copy (`This class`).

### dup (self, deep=False, **items) |
Duplicate this instance, replacing some attributes. Arguments: `deep` - If `True`, duplicate deep, otherwise shallow (`bool`). `items` - Attributes to be changed (`any`), including optional `name` (`str`). Returns: The duplicate (`This class`). Raises: `AttributeError` - Some `items` invalid.

### methodname (self, which) |
Get a method `[module.]class.method` name of this object (`str`). Arguments: `which` - The method (`callable`).

### rename (self, name) |
Change the name. Arguments: `name` - The new name (`str`). Returns: The previous name (`str`).

### renamed (self, name) |
Change the name. Arguments: `name` - The new name (`str`). Returns: This instance (`str`).

### toStr2 (self, **kwds) |
DEPRECATED on 23.10.07, use method `toRepr`. Decorators: `@deprecated_method`

Property Details

### classname Get this object's `[module.]class` name (`str`), see property `.classnaming` and function `classnaming`. Get method: classname(self) - Get this object's `[module.]class` name (`str`), see property `.classnaming` and function `classnaming`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### classnaming Class `property` with a `.name` attribute. Get method: classnaming(self) - Get the class naming (`bool`), see function `classnaming`. Set method: classnaming(self, prefixed) - Set the class naming for `[module.].class` names (`bool`) to `True` to include the module name.

### iteration Get the most recent iteration number (`int`) or `None` if not available or not applicable. Get method: iteration(self) - Get the most recent iteration number (`int`) or `None` if not available or not applicable. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. Note: The interation number may be an aggregate number over several, nested functions.

### name Class `property` with a `.name` attribute. Get method: name(self) - Get the name (`str`). Set method: name(self, name) - Set the `name=NN` (`str`).

### named Get the name or class name or `""` (`str`). Get method: named(self) - Get the name or class name or `""` (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### named2 Get the `class` name and/or the repr(name) or `""` (`str`). Get method: named2(self) - Get the `class` name and/or the repr(name) or `""` (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### named3 Get the prefixed `class` name and/or the name or `""` (`str`). Get method: named3(self) - Get the prefixed `class` name and/or the name or `""` (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### named4 Get the `package.module.class` name and/or the name or `""` (`str`). Get method: named4(self) - Get the `package.module.class` name and/or the name or `""` (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### sizeof Get the current size in `bytes` of this instance (`int`). Get method: sizeof(self) - Get the current size in `bytes` of this instance (`int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### typename Get this object's type name (`str`). Get method: typename(self) - Get this object's type name (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.